<?php

declare(strict_types=1);

namespace App\Tests;

use App\UI\DTO\FilterDTO;
use PHPUnit\Framework\TestCase;

final class FilterDTOTest extends TestCase
{
    public function testCreateFromInvalidDataWithAcceptedFilters(): void
    {
        $data = [
            'name' => 'John',
            'age' => 30,
            'invalid_key' => 'should not be included',
        ];

        $acceptFilters = ['name', 'age'];

        $filterDTO = FilterDTO::createFromData($data, $acceptFilters);

        $this->assertInstanceOf(FilterDTO::class, $filterDTO);
        $this->assertSame(
            [
                'name' => 'John',
                'age' => 30,
            ],
            $filterDTO->filters
        );
    }

    public function testCreateFromInvalidDataWithNoAcceptedFilters(): void
    {
        $data = [
            'name' => 'John',
            'age' => 30,
            'invalid_key' => 'should not be included',
        ];

        $acceptFilters = [];

        $filterDTO = FilterDTO::createFromData($data, $acceptFilters);

        $this->assertInstanceOf(FilterDTO::class, $filterDTO);
        $this->assertSame([], $filterDTO->filters);
    }

    public function testCreateFromInvalidDataWithoutMatchingKeys(): void
    {
        $data = [
            'invalid_key1' => 'value1',
            'invalid_key2' => 'value2',
        ];

        $acceptFilters = ['name', 'age'];

        $filterDTO = FilterDTO::createFromData($data, $acceptFilters);

        $this->assertInstanceOf(FilterDTO::class, $filterDTO);
        $this->assertSame([], $filterDTO->filters);
    }
}
